| Title: | TAF Checks |
|---|---|
| Description: | Tools to check TAF analyses. |
| Authors: | Arni Magnusson [aut, cre], Colin Millar [aut] |
| Maintainer: | Arni Magnusson <[email protected]> |
| License: | GPL-3 |
| Version: | 2026.05.23 |
| Built: | 2026-06-09 03:48:04 UTC |
| Source: | https://github.com/ices-tools-prod/qcTAF |
Tools to check TAF analyses.
Quality control:
qc |
run all quality checks |
qc.boot.exists |
boot directory exists |
qc.data.bib.exists |
DATA.bib exists |
qc.data.bib.valid |
DATA.bib is valid |
qc.data.bib.processed |
DATA.bib processed |
qc.data.declared |
data files are declared |
qc.software.bib.exists |
SOFTWARE.bib exists |
qc.software.bib.valid |
SOFTWARE.bib is valid |
qc.software.bib.processed
|
SOFTWARE.bib processed |
qc.software.declared |
software files are declared |
qc.initial.data |
initial data files |
qc.only.relative.paths |
scripts use only relative paths |
qc.any.scripts.exist |
any scripts exist |
qc.all.scripts.exist |
all scripts exist |
Arni Magnusson and Colin Millar.
Useful links:
Run all quality checks for a given analysis.
qc(analysis = ".")qc(analysis = ".")
analysis |
directory containing a TAF analysis. |
Logical vector indicating the result from each test.
The checks are run in the following order:
dir.exists checks if directory exists.
qc.boot.exists checks if boot directory exists.
qc.data.bib.exists checks if DATA.bib exists.
qc.data.bib.valid checks if DATA.bib is valid.
qc.data.bib.processed checks if DATA.bib entries have
been processed.
qc.data.declared checks if data files are declared.
qc.software.bib.exists checks if SOFTWARE.bib exists.
qc.software.bib.valid checks if SOFTWARE.bib is valid.
qc.software.bib.processed checks if SOFTWARE.bib entries
have been processed.
qc.data.declared checks if software files are declared.
qc.initial.data checks if initial data files have the same
contents as boot data files.
qc.any.scripts.exist checks if any scripts exist.
qc.all.scripts.exist checks if all scripts exist.
qc.only.relative.paths checks if scripts use only relative
paths.
qcTAF-package gives an overview of the package.
## Not run: qc("rjm-347d") ## End(Not run)## Not run: qc("rjm-347d") ## End(Not run)
Check if all TAF scripts (data.R, model.R, output.R, and
report.R) exist.
qc.all.scripts.exist(analysis = ".")qc.all.scripts.exist(analysis = ".")
analysis |
directory containing a TAF analysis. |
TRUE if test succeeds, otherwise FALSE.
qc runs all qc.* tests.
qcTAF-package gives an overview of the package.
## Not run: qc.all.scripts.exist("rjm-347d") ## End(Not run)## Not run: qc.all.scripts.exist("rjm-347d") ## End(Not run)
Check if any TAF scripts (data.R, model.R, output.R, and
report.R) exist.
qc.any.scripts.exist(analysis = ".")qc.any.scripts.exist(analysis = ".")
analysis |
directory containing a TAF analysis. |
TRUE if test succeeds, otherwise FALSE.
qc runs all qc.* tests.
qcTAF-package gives an overview of the package.
## Not run: qc.any.scripts.exist("rjm-347d") ## End(Not run)## Not run: qc.any.scripts.exist("rjm-347d") ## End(Not run)
Check if a boot directory exists.
qc.boot.exists(analysis = ".")qc.boot.exists(analysis = ".")
analysis |
directory containing a TAF analysis. |
TRUE if test succeeds, otherwise FALSE.
qc runs all qc.* tests.
qcTAF-package gives an overview of the package.
## Not run: qc.boot.exists("rjm-347d") ## End(Not run)## Not run: qc.boot.exists("rjm-347d") ## End(Not run)
Check if a DATA.bib file exists.
qc.data.bib.exists(analysis = ".")qc.data.bib.exists(analysis = ".")
analysis |
directory containing a TAF analysis. |
TRUE if test succeeds, otherwise FALSE.
qc runs all qc.* tests.
qcTAF-package gives an overview of the package.
## Not run: qc.data.bib.exists("rjm-347d") ## End(Not run)## Not run: qc.data.bib.exists("rjm-347d") ## End(Not run)
Check if a DATA.bib entries appear to have been processed, i.e., found
as files and directories inside the boot folder.
qc.data.bib.processed(analysis = ".")qc.data.bib.processed(analysis = ".")
analysis |
directory containing a TAF analysis. |
TRUE if test succeeds, otherwise FALSE.
qc.data.bib.processed checks if all bib entries have made it into the
boot data folder:
DATA.bib | boot/data
---------+----------
A |
B ==>
C |
qc.data.declared checks if all boot data files were declared as bib
entries:
DATA.bib | boot/data
---------+----------
| A
<== B
| C
When used together, those two functions ensure that DATA.bib and
boot/data contain precisely the same entries.
qc runs all qc.* tests.
qcTAF-package gives an overview of the package.
## Not run: qc.data.bib.processed("rjm-347d") ## End(Not run)## Not run: qc.data.bib.processed("rjm-347d") ## End(Not run)
Check if a DATA.bib file is valid.
qc.data.bib.valid(analysis = ".")qc.data.bib.valid(analysis = ".")
analysis |
directory containing a TAF analysis. |
TRUE if test succeeds, otherwise FALSE.
qc runs all qc.* tests.
qcTAF-package gives an overview of the package.
## Not run: qc.data.bib.valid("rjm-347d") ## End(Not run)## Not run: qc.data.bib.valid("rjm-347d") ## End(Not run)
Check if all files in the boot data folder are declared in the
DATA.bib file.
qc.data.declared(analysis = ".")qc.data.declared(analysis = ".")
analysis |
directory containing a TAF analysis. |
TRUE if test succeeds, otherwise FALSE.
qc.data.bib.processed checks if all bib entries have made it into the
boot data folder:
DATA.bib | boot/data
---------+----------
A |
B ==>
C |
qc.data.declared checks if all boot data files were declared as bib
entries:
DATA.bib | boot/data
---------+----------
| A
<== B
| C
When used together, those two functions ensure that DATA.bib and
boot/data contain precisely the same entries.
qc runs all qc.* tests.
qcTAF-package gives an overview of the package.
## Not run: qc.data.declared("rjm-347d") ## End(Not run)## Not run: qc.data.declared("rjm-347d") ## End(Not run)
Check if initial data files have the same contents as boot data files.
qc.initial.data(analysis = ".")qc.initial.data(analysis = ".")
analysis |
directory containing a TAF analysis. |
TRUE if test succeeds, otherwise FALSE.
qc runs all qc.* tests.
qcTAF-package gives an overview of the package.
## Not run: qc.initial.data("rjm-347d") ## End(Not run)## Not run: qc.initial.data("rjm-347d") ## End(Not run)
Check if scripts (*.R, *.Rmd, Rnw, *.qmd) use
only relative paths.
qc.only.relative.paths(analysis = ".")qc.only.relative.paths(analysis = ".")
analysis |
directory containing a TAF analysis. |
TRUE if test succeeds, otherwise FALSE.
qc runs all qc.* tests.
qcTAF-package gives an overview of the package.
## Not run: qc.only.relative.paths("rjm-347d") ## End(Not run)## Not run: qc.only.relative.paths("rjm-347d") ## End(Not run)
Check if a SOFTWARE.bib file exists.
qc.software.bib.exists(analysis = ".")qc.software.bib.exists(analysis = ".")
analysis |
directory containing a TAF analysis. |
TRUE if test succeeds, otherwise FALSE.
qc runs all qc.* tests.
qcTAF-package gives an overview of the package.
## Not run: qc.software.bib.exists("rjm-347d") ## End(Not run)## Not run: qc.software.bib.exists("rjm-347d") ## End(Not run)
Check if a SOFTWARE.bib entries appear to have been processed, i.e.,
found as files and directories inside the boot folder.
qc.software.bib.processed(analysis = ".")qc.software.bib.processed(analysis = ".")
analysis |
directory containing a TAF analysis. |
TRUE if test succeeds, otherwise FALSE.
qc.software.bib.processed checks if all bib entries have made it into
the boot software folder:
SOFTWARE.bib | boot/software
-------------+--------------
A |
B ==>
C |
qc.software.declared checks if all boot software files were declared
as bib entries:
SOFTWARE.bib | boot/software
-------------+--------------
| A
<== B
| C
When used together, those two functions ensure that SOFTWARE.bib and
boot/software contain precisely the same entries.
qc runs all qc.* tests.
qcTAF-package gives an overview of the package.
## Not run: qc.software.bib.processed("rjm-347d") ## End(Not run)## Not run: qc.software.bib.processed("rjm-347d") ## End(Not run)
Check if a SOFTWARE.bib file is valid.
qc.software.bib.valid(analysis = ".")qc.software.bib.valid(analysis = ".")
analysis |
directory containing a TAF analysis. |
TRUE if test succeeds, otherwise FALSE.
qc runs all qc.* tests.
qcTAF-package gives an overview of the package.
## Not run: qc.software.bib.valid("rjm-347d") ## End(Not run)## Not run: qc.software.bib.valid("rjm-347d") ## End(Not run)
Check if all files in the boot software folder are declared in the
SOFTWARE.bib file.
qc.software.declared(analysis = ".")qc.software.declared(analysis = ".")
analysis |
directory containing a TAF analysis. |
TRUE if test succeeds, otherwise FALSE.
qc.software.bib.processed checks if all bib entries have made it into
the boot software folder:
SOFTWARE.bib | boot/software
-------------+--------------
A |
B ==>
C |
qc.software.declared checks if all boot software files were declared
as bib entries:
SOFTWARE.bib | boot/software
-------------+--------------
| A
<== B
| C
When used together, those two functions ensure that SOFTWARE.bib and
boot/software contain precisely the same entries.
qc runs all qc.* tests.
qcTAF-package gives an overview of the package.
## Not run: qc.software.declared("rjm-347d") ## End(Not run)## Not run: qc.software.declared("rjm-347d") ## End(Not run)